@@ -1,7 +1,9 @@
 package Sah::Schema::perl::funcname;
 
-our $DATE = '2019-12-15'; # DATE
-our $VERSION = '0.026'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2020-02-15'; # DATE
+our $DIST = 'Sah-Schemas-Perl'; # DIST
+our $VERSION = '0.027'; # VERSION
 
 our $schema = [str => {
     summary => 'Perl function name, either qualified or unqualified with a package name',
@@ -38,7 +40,7 @@ Sah::Schema::perl::funcname - Perl function name, either qualified or unqualifie
 
 =head1 VERSION
 
-This document describes version 0.026 of Sah::Schema::perl::funcname (from Perl distribution Sah-Schemas-Perl), released on 2019-12-15.
+This document describes version 0.027 of Sah::Schema::perl::funcname (from Perl distribution Sah-Schemas-Perl), released on 2020-02-15.
 
 =head1 DESCRIPTION
 
@@ -78,7 +80,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019, 2018, 2017, 2016 by perlancar@cpan.org.
+This software is copyright (c) 2020, 2019, 2018, 2017, 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
